Processor.processor
===================

.. automodule:: Processor.processor

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      call_pipeline_with_ack
      get_hostname_output_path
      init_connection
      init_pipeline
      processor
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      Listener
      ListnerStats
      Message
   
   

   
   
   



